# coding: utf-8

"""
    Emby Server REST API (BETA)
"""

import pprint
import re  # noqa: F401

import six

class PackageInfo(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'name': 'str',
        'short_description': 'str',
        'overview': 'str',
        'is_premium': 'bool',
        'adult': 'bool',
        'rich_desc_url': 'str',
        'thumb_image': 'str',
        'preview_image': 'str',
        'type': 'str',
        'target_filename': 'str',
        'owner': 'str',
        'category': 'str',
        'tile_color': 'str',
        'feature_id': 'str',
        'price': 'float',
        'target_system': 'PackageTargetSystem',
        'guid': 'str',
        'is_registered': 'bool',
        'exp_date': 'datetime',
        'versions': 'list[PackageVersionInfo]',
        'enable_in_app_store': 'bool',
        'installs': 'int'
    }

    attribute_map = {
        'id': 'id',
        'name': 'name',
        'short_description': 'shortDescription',
        'overview': 'overview',
        'is_premium': 'isPremium',
        'adult': 'adult',
        'rich_desc_url': 'richDescUrl',
        'thumb_image': 'thumbImage',
        'preview_image': 'previewImage',
        'type': 'type',
        'target_filename': 'targetFilename',
        'owner': 'owner',
        'category': 'category',
        'tile_color': 'tileColor',
        'feature_id': 'featureId',
        'price': 'price',
        'target_system': 'targetSystem',
        'guid': 'guid',
        'is_registered': 'isRegistered',
        'exp_date': 'expDate',
        'versions': 'versions',
        'enable_in_app_store': 'enableInAppStore',
        'installs': 'installs'
    }

    def __init__(self, id=None, name=None, short_description=None, overview=None, is_premium=None, adult=None, rich_desc_url=None, thumb_image=None, preview_image=None, type=None, target_filename=None, owner=None, category=None, tile_color=None, feature_id=None, price=None, target_system=None, guid=None, is_registered=None, exp_date=None, versions=None, enable_in_app_store=None, installs=None):  # noqa: E501
        """PackageInfo - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._name = None
        self._short_description = None
        self._overview = None
        self._is_premium = None
        self._adult = None
        self._rich_desc_url = None
        self._thumb_image = None
        self._preview_image = None
        self._type = None
        self._target_filename = None
        self._owner = None
        self._category = None
        self._tile_color = None
        self._feature_id = None
        self._price = None
        self._target_system = None
        self._guid = None
        self._is_registered = None
        self._exp_date = None
        self._versions = None
        self._enable_in_app_store = None
        self._installs = None
        self.discriminator = None
        if id is not None:
            self.id = id
        if name is not None:
            self.name = name
        if short_description is not None:
            self.short_description = short_description
        if overview is not None:
            self.overview = overview
        if is_premium is not None:
            self.is_premium = is_premium
        if adult is not None:
            self.adult = adult
        if rich_desc_url is not None:
            self.rich_desc_url = rich_desc_url
        if thumb_image is not None:
            self.thumb_image = thumb_image
        if preview_image is not None:
            self.preview_image = preview_image
        if type is not None:
            self.type = type
        if target_filename is not None:
            self.target_filename = target_filename
        if owner is not None:
            self.owner = owner
        if category is not None:
            self.category = category
        if tile_color is not None:
            self.tile_color = tile_color
        if feature_id is not None:
            self.feature_id = feature_id
        if price is not None:
            self.price = price
        if target_system is not None:
            self.target_system = target_system
        if guid is not None:
            self.guid = guid
        if is_registered is not None:
            self.is_registered = is_registered
        if exp_date is not None:
            self.exp_date = exp_date
        if versions is not None:
            self.versions = versions
        if enable_in_app_store is not None:
            self.enable_in_app_store = enable_in_app_store
        if installs is not None:
            self.installs = installs

    @property
    def id(self):
        """Gets the id of this PackageInfo.  # noqa: E501

        The internal id of this package.  # noqa: E501

        :return: The id of this PackageInfo.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this PackageInfo.

        The internal id of this package.  # noqa: E501

        :param id: The id of this PackageInfo.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def name(self):
        """Gets the name of this PackageInfo.  # noqa: E501

        The name.  # noqa: E501

        :return: The name of this PackageInfo.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this PackageInfo.

        The name.  # noqa: E501

        :param name: The name of this PackageInfo.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def short_description(self):
        """Gets the short_description of this PackageInfo.  # noqa: E501

        The short description.  # noqa: E501

        :return: The short_description of this PackageInfo.  # noqa: E501
        :rtype: str
        """
        return self._short_description

    @short_description.setter
    def short_description(self, short_description):
        """Sets the short_description of this PackageInfo.

        The short description.  # noqa: E501

        :param short_description: The short_description of this PackageInfo.  # noqa: E501
        :type: str
        """

        self._short_description = short_description

    @property
    def overview(self):
        """Gets the overview of this PackageInfo.  # noqa: E501

        The overview.  # noqa: E501

        :return: The overview of this PackageInfo.  # noqa: E501
        :rtype: str
        """
        return self._overview

    @overview.setter
    def overview(self, overview):
        """Sets the overview of this PackageInfo.

        The overview.  # noqa: E501

        :param overview: The overview of this PackageInfo.  # noqa: E501
        :type: str
        """

        self._overview = overview

    @property
    def is_premium(self):
        """Gets the is_premium of this PackageInfo.  # noqa: E501

        A value indicating whether this instance is premium.  # noqa: E501

        :return: The is_premium of this PackageInfo.  # noqa: E501
        :rtype: bool
        """
        return self._is_premium

    @is_premium.setter
    def is_premium(self, is_premium):
        """Sets the is_premium of this PackageInfo.

        A value indicating whether this instance is premium.  # noqa: E501

        :param is_premium: The is_premium of this PackageInfo.  # noqa: E501
        :type: bool
        """

        self._is_premium = is_premium

    @property
    def adult(self):
        """Gets the adult of this PackageInfo.  # noqa: E501

        A value indicating whether this instance is adult only content.  # noqa: E501

        :return: The adult of this PackageInfo.  # noqa: E501
        :rtype: bool
        """
        return self._adult

    @adult.setter
    def adult(self, adult):
        """Sets the adult of this PackageInfo.

        A value indicating whether this instance is adult only content.  # noqa: E501

        :param adult: The adult of this PackageInfo.  # noqa: E501
        :type: bool
        """

        self._adult = adult

    @property
    def rich_desc_url(self):
        """Gets the rich_desc_url of this PackageInfo.  # noqa: E501

        The rich desc URL.  # noqa: E501

        :return: The rich_desc_url of this PackageInfo.  # noqa: E501
        :rtype: str
        """
        return self._rich_desc_url

    @rich_desc_url.setter
    def rich_desc_url(self, rich_desc_url):
        """Sets the rich_desc_url of this PackageInfo.

        The rich desc URL.  # noqa: E501

        :param rich_desc_url: The rich_desc_url of this PackageInfo.  # noqa: E501
        :type: str
        """

        self._rich_desc_url = rich_desc_url

    @property
    def thumb_image(self):
        """Gets the thumb_image of this PackageInfo.  # noqa: E501

        The thumb image.  # noqa: E501

        :return: The thumb_image of this PackageInfo.  # noqa: E501
        :rtype: str
        """
        return self._thumb_image

    @thumb_image.setter
    def thumb_image(self, thumb_image):
        """Sets the thumb_image of this PackageInfo.

        The thumb image.  # noqa: E501

        :param thumb_image: The thumb_image of this PackageInfo.  # noqa: E501
        :type: str
        """

        self._thumb_image = thumb_image

    @property
    def preview_image(self):
        """Gets the preview_image of this PackageInfo.  # noqa: E501

        The preview image.  # noqa: E501

        :return: The preview_image of this PackageInfo.  # noqa: E501
        :rtype: str
        """
        return self._preview_image

    @preview_image.setter
    def preview_image(self, preview_image):
        """Sets the preview_image of this PackageInfo.

        The preview image.  # noqa: E501

        :param preview_image: The preview_image of this PackageInfo.  # noqa: E501
        :type: str
        """

        self._preview_image = preview_image

    @property
    def type(self):
        """Gets the type of this PackageInfo.  # noqa: E501

        The type.  # noqa: E501

        :return: The type of this PackageInfo.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this PackageInfo.

        The type.  # noqa: E501

        :param type: The type of this PackageInfo.  # noqa: E501
        :type: str
        """

        self._type = type

    @property
    def target_filename(self):
        """Gets the target_filename of this PackageInfo.  # noqa: E501

        The target filename.  # noqa: E501

        :return: The target_filename of this PackageInfo.  # noqa: E501
        :rtype: str
        """
        return self._target_filename

    @target_filename.setter
    def target_filename(self, target_filename):
        """Sets the target_filename of this PackageInfo.

        The target filename.  # noqa: E501

        :param target_filename: The target_filename of this PackageInfo.  # noqa: E501
        :type: str
        """

        self._target_filename = target_filename

    @property
    def owner(self):
        """Gets the owner of this PackageInfo.  # noqa: E501

        The owner.  # noqa: E501

        :return: The owner of this PackageInfo.  # noqa: E501
        :rtype: str
        """
        return self._owner

    @owner.setter
    def owner(self, owner):
        """Sets the owner of this PackageInfo.

        The owner.  # noqa: E501

        :param owner: The owner of this PackageInfo.  # noqa: E501
        :type: str
        """

        self._owner = owner

    @property
    def category(self):
        """Gets the category of this PackageInfo.  # noqa: E501

        The category.  # noqa: E501

        :return: The category of this PackageInfo.  # noqa: E501
        :rtype: str
        """
        return self._category

    @category.setter
    def category(self, category):
        """Sets the category of this PackageInfo.

        The category.  # noqa: E501

        :param category: The category of this PackageInfo.  # noqa: E501
        :type: str
        """

        self._category = category

    @property
    def tile_color(self):
        """Gets the tile_color of this PackageInfo.  # noqa: E501

        The catalog tile color.  # noqa: E501

        :return: The tile_color of this PackageInfo.  # noqa: E501
        :rtype: str
        """
        return self._tile_color

    @tile_color.setter
    def tile_color(self, tile_color):
        """Sets the tile_color of this PackageInfo.

        The catalog tile color.  # noqa: E501

        :param tile_color: The tile_color of this PackageInfo.  # noqa: E501
        :type: str
        """

        self._tile_color = tile_color

    @property
    def feature_id(self):
        """Gets the feature_id of this PackageInfo.  # noqa: E501

        The feature id of this package (if premium).  # noqa: E501

        :return: The feature_id of this PackageInfo.  # noqa: E501
        :rtype: str
        """
        return self._feature_id

    @feature_id.setter
    def feature_id(self, feature_id):
        """Sets the feature_id of this PackageInfo.

        The feature id of this package (if premium).  # noqa: E501

        :param feature_id: The feature_id of this PackageInfo.  # noqa: E501
        :type: str
        """

        self._feature_id = feature_id

    @property
    def price(self):
        """Gets the price of this PackageInfo.  # noqa: E501

        The price for this package (if premium).  # noqa: E501

        :return: The price of this PackageInfo.  # noqa: E501
        :rtype: float
        """
        return self._price

    @price.setter
    def price(self, price):
        """Sets the price of this PackageInfo.

        The price for this package (if premium).  # noqa: E501

        :param price: The price of this PackageInfo.  # noqa: E501
        :type: float
        """

        self._price = price

    @property
    def target_system(self):
        """Gets the target_system of this PackageInfo.  # noqa: E501


        :return: The target_system of this PackageInfo.  # noqa: E501
        :rtype: PackageTargetSystem
        """
        return self._target_system

    @target_system.setter
    def target_system(self, target_system):
        """Sets the target_system of this PackageInfo.


        :param target_system: The target_system of this PackageInfo.  # noqa: E501
        :type: PackageTargetSystem
        """

        self._target_system = target_system

    @property
    def guid(self):
        """Gets the guid of this PackageInfo.  # noqa: E501

        The guid of the assembly associated with this package (if a plug\\-in). This is used to identify the proper item for automatic updates.  # noqa: E501

        :return: The guid of this PackageInfo.  # noqa: E501
        :rtype: str
        """
        return self._guid

    @guid.setter
    def guid(self, guid):
        """Sets the guid of this PackageInfo.

        The guid of the assembly associated with this package (if a plug\\-in). This is used to identify the proper item for automatic updates.  # noqa: E501

        :param guid: The guid of this PackageInfo.  # noqa: E501
        :type: str
        """

        self._guid = guid

    @property
    def is_registered(self):
        """Gets the is_registered of this PackageInfo.  # noqa: E501

        Whether or not this package is registered.  # noqa: E501

        :return: The is_registered of this PackageInfo.  # noqa: E501
        :rtype: bool
        """
        return self._is_registered

    @is_registered.setter
    def is_registered(self, is_registered):
        """Sets the is_registered of this PackageInfo.

        Whether or not this package is registered.  # noqa: E501

        :param is_registered: The is_registered of this PackageInfo.  # noqa: E501
        :type: bool
        """

        self._is_registered = is_registered

    @property
    def exp_date(self):
        """Gets the exp_date of this PackageInfo.  # noqa: E501

        The expiration date for this package.  # noqa: E501

        :return: The exp_date of this PackageInfo.  # noqa: E501
        :rtype: datetime
        """
        return self._exp_date

    @exp_date.setter
    def exp_date(self, exp_date):
        """Sets the exp_date of this PackageInfo.

        The expiration date for this package.  # noqa: E501

        :param exp_date: The exp_date of this PackageInfo.  # noqa: E501
        :type: datetime
        """

        self._exp_date = exp_date

    @property
    def versions(self):
        """Gets the versions of this PackageInfo.  # noqa: E501

        The versions.  # noqa: E501

        :return: The versions of this PackageInfo.  # noqa: E501
        :rtype: list[PackageVersionInfo]
        """
        return self._versions

    @versions.setter
    def versions(self, versions):
        """Sets the versions of this PackageInfo.

        The versions.  # noqa: E501

        :param versions: The versions of this PackageInfo.  # noqa: E501
        :type: list[PackageVersionInfo]
        """

        self._versions = versions

    @property
    def enable_in_app_store(self):
        """Gets the enable_in_app_store of this PackageInfo.  # noqa: E501

        A value indicating whether \\[enable in application store\\].  # noqa: E501

        :return: The enable_in_app_store of this PackageInfo.  # noqa: E501
        :rtype: bool
        """
        return self._enable_in_app_store

    @enable_in_app_store.setter
    def enable_in_app_store(self, enable_in_app_store):
        """Sets the enable_in_app_store of this PackageInfo.

        A value indicating whether \\[enable in application store\\].  # noqa: E501

        :param enable_in_app_store: The enable_in_app_store of this PackageInfo.  # noqa: E501
        :type: bool
        """

        self._enable_in_app_store = enable_in_app_store

    @property
    def installs(self):
        """Gets the installs of this PackageInfo.  # noqa: E501

        The installs.  # noqa: E501

        :return: The installs of this PackageInfo.  # noqa: E501
        :rtype: int
        """
        return self._installs

    @installs.setter
    def installs(self, installs):
        """Sets the installs of this PackageInfo.

        The installs.  # noqa: E501

        :param installs: The installs of this PackageInfo.  # noqa: E501
        :type: int
        """

        self._installs = installs

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(PackageInfo, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PackageInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Emby Server REST API (BETA)
"""

import pprint
import re  # noqa: F401

import six

class MBBackupApiAllBackupsInfo(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'full_backup_info': 'MBBackupBackupInfo',
        'light_backups': 'list[MBBackupBackupInfo]'
    }

    attribute_map = {
        'full_backup_info': 'FullBackupInfo',
        'light_backups': 'LightBackups'
    }

    def __init__(self, full_backup_info=None, light_backups=None):  # noqa: E501
        """MBBackupApiAllBackupsInfo - a model defined in Swagger"""  # noqa: E501
        self._full_backup_info = None
        self._light_backups = None
        self.discriminator = None
        if full_backup_info is not None:
            self.full_backup_info = full_backup_info
        if light_backups is not None:
            self.light_backups = light_backups

    @property
    def full_backup_info(self):
        """Gets the full_backup_info of this MBBackupApiAllBackupsInfo.  # noqa: E501


        :return: The full_backup_info of this MBBackupApiAllBackupsInfo.  # noqa: E501
        :rtype: MBBackupBackupInfo
        """
        return self._full_backup_info

    @full_backup_info.setter
    def full_backup_info(self, full_backup_info):
        """Sets the full_backup_info of this MBBackupApiAllBackupsInfo.


        :param full_backup_info: The full_backup_info of this MBBackupApiAllBackupsInfo.  # noqa: E501
        :type: MBBackupBackupInfo
        """

        self._full_backup_info = full_backup_info

    @property
    def light_backups(self):
        """Gets the light_backups of this MBBackupApiAllBackupsInfo.  # noqa: E501


        :return: The light_backups of this MBBackupApiAllBackupsInfo.  # noqa: E501
        :rtype: list[MBBackupBackupInfo]
        """
        return self._light_backups

    @light_backups.setter
    def light_backups(self, light_backups):
        """Sets the light_backups of this MBBackupApiAllBackupsInfo.


        :param light_backups: The light_backups of this MBBackupApiAllBackupsInfo.  # noqa: E501
        :type: list[MBBackupBackupInfo]
        """

        self._light_backups = light_backups

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(MBBackupApiAllBackupsInfo, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MBBackupApiAllBackupsInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Emby Server REST API (BETA)
"""

import pprint
import re  # noqa: F401

import six

class ApiConfigurationPageInfo(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'enable_in_main_menu': 'bool',
        'enable_in_user_menu': 'bool',
        'feature_id': 'str',
        'menu_section': 'str',
        'menu_icon': 'str',
        'display_name': 'str',
        'configuration_page_type': 'PluginsConfigurationPageType',
        'plugin_id': 'str',
        'href': 'str',
        'nav_menu_id': 'str',
        'plugin': 'CommonPluginsIPlugin',
        'translations': 'list[str]'
    }

    attribute_map = {
        'name': 'Name',
        'enable_in_main_menu': 'EnableInMainMenu',
        'enable_in_user_menu': 'EnableInUserMenu',
        'feature_id': 'FeatureId',
        'menu_section': 'MenuSection',
        'menu_icon': 'MenuIcon',
        'display_name': 'DisplayName',
        'configuration_page_type': 'ConfigurationPageType',
        'plugin_id': 'PluginId',
        'href': 'Href',
        'nav_menu_id': 'NavMenuId',
        'plugin': 'Plugin',
        'translations': 'Translations'
    }

    def __init__(self, name=None, enable_in_main_menu=None, enable_in_user_menu=None, feature_id=None, menu_section=None, menu_icon=None, display_name=None, configuration_page_type=None, plugin_id=None, href=None, nav_menu_id=None, plugin=None, translations=None):  # noqa: E501
        """ApiConfigurationPageInfo - a model defined in Swagger"""  # noqa: E501
        self._name = None
        self._enable_in_main_menu = None
        self._enable_in_user_menu = None
        self._feature_id = None
        self._menu_section = None
        self._menu_icon = None
        self._display_name = None
        self._configuration_page_type = None
        self._plugin_id = None
        self._href = None
        self._nav_menu_id = None
        self._plugin = None
        self._translations = None
        self.discriminator = None
        if name is not None:
            self.name = name
        if enable_in_main_menu is not None:
            self.enable_in_main_menu = enable_in_main_menu
        if enable_in_user_menu is not None:
            self.enable_in_user_menu = enable_in_user_menu
        if feature_id is not None:
            self.feature_id = feature_id
        if menu_section is not None:
            self.menu_section = menu_section
        if menu_icon is not None:
            self.menu_icon = menu_icon
        if display_name is not None:
            self.display_name = display_name
        if configuration_page_type is not None:
            self.configuration_page_type = configuration_page_type
        if plugin_id is not None:
            self.plugin_id = plugin_id
        if href is not None:
            self.href = href
        if nav_menu_id is not None:
            self.nav_menu_id = nav_menu_id
        if plugin is not None:
            self.plugin = plugin
        if translations is not None:
            self.translations = translations

    @property
    def name(self):
        """Gets the name of this ApiConfigurationPageInfo.  # noqa: E501


        :return: The name of this ApiConfigurationPageInfo.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ApiConfigurationPageInfo.


        :param name: The name of this ApiConfigurationPageInfo.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def enable_in_main_menu(self):
        """Gets the enable_in_main_menu of this ApiConfigurationPageInfo.  # noqa: E501


        :return: The enable_in_main_menu of this ApiConfigurationPageInfo.  # noqa: E501
        :rtype: bool
        """
        return self._enable_in_main_menu

    @enable_in_main_menu.setter
    def enable_in_main_menu(self, enable_in_main_menu):
        """Sets the enable_in_main_menu of this ApiConfigurationPageInfo.


        :param enable_in_main_menu: The enable_in_main_menu of this ApiConfigurationPageInfo.  # noqa: E501
        :type: bool
        """

        self._enable_in_main_menu = enable_in_main_menu

    @property
    def enable_in_user_menu(self):
        """Gets the enable_in_user_menu of this ApiConfigurationPageInfo.  # noqa: E501


        :return: The enable_in_user_menu of this ApiConfigurationPageInfo.  # noqa: E501
        :rtype: bool
        """
        return self._enable_in_user_menu

    @enable_in_user_menu.setter
    def enable_in_user_menu(self, enable_in_user_menu):
        """Sets the enable_in_user_menu of this ApiConfigurationPageInfo.


        :param enable_in_user_menu: The enable_in_user_menu of this ApiConfigurationPageInfo.  # noqa: E501
        :type: bool
        """

        self._enable_in_user_menu = enable_in_user_menu

    @property
    def feature_id(self):
        """Gets the feature_id of this ApiConfigurationPageInfo.  # noqa: E501


        :return: The feature_id of this ApiConfigurationPageInfo.  # noqa: E501
        :rtype: str
        """
        return self._feature_id

    @feature_id.setter
    def feature_id(self, feature_id):
        """Sets the feature_id of this ApiConfigurationPageInfo.


        :param feature_id: The feature_id of this ApiConfigurationPageInfo.  # noqa: E501
        :type: str
        """

        self._feature_id = feature_id

    @property
    def menu_section(self):
        """Gets the menu_section of this ApiConfigurationPageInfo.  # noqa: E501


        :return: The menu_section of this ApiConfigurationPageInfo.  # noqa: E501
        :rtype: str
        """
        return self._menu_section

    @menu_section.setter
    def menu_section(self, menu_section):
        """Sets the menu_section of this ApiConfigurationPageInfo.


        :param menu_section: The menu_section of this ApiConfigurationPageInfo.  # noqa: E501
        :type: str
        """

        self._menu_section = menu_section

    @property
    def menu_icon(self):
        """Gets the menu_icon of this ApiConfigurationPageInfo.  # noqa: E501


        :return: The menu_icon of this ApiConfigurationPageInfo.  # noqa: E501
        :rtype: str
        """
        return self._menu_icon

    @menu_icon.setter
    def menu_icon(self, menu_icon):
        """Sets the menu_icon of this ApiConfigurationPageInfo.


        :param menu_icon: The menu_icon of this ApiConfigurationPageInfo.  # noqa: E501
        :type: str
        """

        self._menu_icon = menu_icon

    @property
    def display_name(self):
        """Gets the display_name of this ApiConfigurationPageInfo.  # noqa: E501


        :return: The display_name of this ApiConfigurationPageInfo.  # noqa: E501
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """Sets the display_name of this ApiConfigurationPageInfo.


        :param display_name: The display_name of this ApiConfigurationPageInfo.  # noqa: E501
        :type: str
        """

        self._display_name = display_name

    @property
    def configuration_page_type(self):
        """Gets the configuration_page_type of this ApiConfigurationPageInfo.  # noqa: E501


        :return: The configuration_page_type of this ApiConfigurationPageInfo.  # noqa: E501
        :rtype: PluginsConfigurationPageType
        """
        return self._configuration_page_type

    @configuration_page_type.setter
    def configuration_page_type(self, configuration_page_type):
        """Sets the configuration_page_type of this ApiConfigurationPageInfo.


        :param configuration_page_type: The configuration_page_type of this ApiConfigurationPageInfo.  # noqa: E501
        :type: PluginsConfigurationPageType
        """

        self._configuration_page_type = configuration_page_type

    @property
    def plugin_id(self):
        """Gets the plugin_id of this ApiConfigurationPageInfo.  # noqa: E501


        :return: The plugin_id of this ApiConfigurationPageInfo.  # noqa: E501
        :rtype: str
        """
        return self._plugin_id

    @plugin_id.setter
    def plugin_id(self, plugin_id):
        """Sets the plugin_id of this ApiConfigurationPageInfo.


        :param plugin_id: The plugin_id of this ApiConfigurationPageInfo.  # noqa: E501
        :type: str
        """

        self._plugin_id = plugin_id

    @property
    def href(self):
        """Gets the href of this ApiConfigurationPageInfo.  # noqa: E501


        :return: The href of this ApiConfigurationPageInfo.  # noqa: E501
        :rtype: str
        """
        return self._href

    @href.setter
    def href(self, href):
        """Sets the href of this ApiConfigurationPageInfo.


        :param href: The href of this ApiConfigurationPageInfo.  # noqa: E501
        :type: str
        """

        self._href = href

    @property
    def nav_menu_id(self):
        """Gets the nav_menu_id of this ApiConfigurationPageInfo.  # noqa: E501


        :return: The nav_menu_id of this ApiConfigurationPageInfo.  # noqa: E501
        :rtype: str
        """
        return self._nav_menu_id

    @nav_menu_id.setter
    def nav_menu_id(self, nav_menu_id):
        """Sets the nav_menu_id of this ApiConfigurationPageInfo.


        :param nav_menu_id: The nav_menu_id of this ApiConfigurationPageInfo.  # noqa: E501
        :type: str
        """

        self._nav_menu_id = nav_menu_id

    @property
    def plugin(self):
        """Gets the plugin of this ApiConfigurationPageInfo.  # noqa: E501


        :return: The plugin of this ApiConfigurationPageInfo.  # noqa: E501
        :rtype: CommonPluginsIPlugin
        """
        return self._plugin

    @plugin.setter
    def plugin(self, plugin):
        """Sets the plugin of this ApiConfigurationPageInfo.


        :param plugin: The plugin of this ApiConfigurationPageInfo.  # noqa: E501
        :type: CommonPluginsIPlugin
        """

        self._plugin = plugin

    @property
    def translations(self):
        """Gets the translations of this ApiConfigurationPageInfo.  # noqa: E501


        :return: The translations of this ApiConfigurationPageInfo.  # noqa: E501
        :rtype: list[str]
        """
        return self._translations

    @translations.setter
    def translations(self, translations):
        """Sets the translations of this ApiConfigurationPageInfo.


        :param translations: The translations of this ApiConfigurationPageInfo.  # noqa: E501
        :type: list[str]
        """

        self._translations = translations

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ApiConfigurationPageInfo, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ApiConfigurationPageInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Emby Server REST API (BETA)
"""

import pprint
import re  # noqa: F401

import six

class VideoCodecBase(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'codec_device_info': 'CommonInterfacesICodecDeviceInfo',
        'codec_kind': 'CodecKinds',
        'media_type_name': 'str',
        'video_media_type': 'VideoMediaTypes',
        'min_width': 'int',
        'max_width': 'int',
        'min_height': 'int',
        'max_height': 'int',
        'width_alignment': 'int',
        'height_alignment': 'int',
        'max_bit_rate': 'BitRate',
        'supported_color_formats': 'list[ColorFormats]',
        'supported_color_format_strings': 'list[str]',
        'profile_and_level_information': 'list[ProfileLevelInformation]',
        'id': 'str',
        'direction': 'CodecDirections',
        'name': 'str',
        'description': 'str',
        'framework_codec': 'str',
        'is_hardware_codec': 'bool',
        'secondary_framework': 'SecondaryFrameworks',
        'secondary_framework_codec': 'str',
        'max_instance_count': 'int',
        'is_enabled_by_default': 'bool',
        'default_priority': 'int'
    }

    attribute_map = {
        'codec_device_info': 'CodecDeviceInfo',
        'codec_kind': 'CodecKind',
        'media_type_name': 'MediaTypeName',
        'video_media_type': 'VideoMediaType',
        'min_width': 'MinWidth',
        'max_width': 'MaxWidth',
        'min_height': 'MinHeight',
        'max_height': 'MaxHeight',
        'width_alignment': 'WidthAlignment',
        'height_alignment': 'HeightAlignment',
        'max_bit_rate': 'MaxBitRate',
        'supported_color_formats': 'SupportedColorFormats',
        'supported_color_format_strings': 'SupportedColorFormatStrings',
        'profile_and_level_information': 'ProfileAndLevelInformation',
        'id': 'Id',
        'direction': 'Direction',
        'name': 'Name',
        'description': 'Description',
        'framework_codec': 'FrameworkCodec',
        'is_hardware_codec': 'IsHardwareCodec',
        'secondary_framework': 'SecondaryFramework',
        'secondary_framework_codec': 'SecondaryFrameworkCodec',
        'max_instance_count': 'MaxInstanceCount',
        'is_enabled_by_default': 'IsEnabledByDefault',
        'default_priority': 'DefaultPriority'
    }

    def __init__(self, codec_device_info=None, codec_kind=None, media_type_name=None, video_media_type=None, min_width=None, max_width=None, min_height=None, max_height=None, width_alignment=None, height_alignment=None, max_bit_rate=None, supported_color_formats=None, supported_color_format_strings=None, profile_and_level_information=None, id=None, direction=None, name=None, description=None, framework_codec=None, is_hardware_codec=None, secondary_framework=None, secondary_framework_codec=None, max_instance_count=None, is_enabled_by_default=None, default_priority=None):  # noqa: E501
        """VideoCodecBase - a model defined in Swagger"""  # noqa: E501
        self._codec_device_info = None
        self._codec_kind = None
        self._media_type_name = None
        self._video_media_type = None
        self._min_width = None
        self._max_width = None
        self._min_height = None
        self._max_height = None
        self._width_alignment = None
        self._height_alignment = None
        self._max_bit_rate = None
        self._supported_color_formats = None
        self._supported_color_format_strings = None
        self._profile_and_level_information = None
        self._id = None
        self._direction = None
        self._name = None
        self._description = None
        self._framework_codec = None
        self._is_hardware_codec = None
        self._secondary_framework = None
        self._secondary_framework_codec = None
        self._max_instance_count = None
        self._is_enabled_by_default = None
        self._default_priority = None
        self.discriminator = None
        if codec_device_info is not None:
            self.codec_device_info = codec_device_info
        if codec_kind is not None:
            self.codec_kind = codec_kind
        if media_type_name is not None:
            self.media_type_name = media_type_name
        if video_media_type is not None:
            self.video_media_type = video_media_type
        if min_width is not None:
            self.min_width = min_width
        if max_width is not None:
            self.max_width = max_width
        if min_height is not None:
            self.min_height = min_height
        if max_height is not None:
            self.max_height = max_height
        if width_alignment is not None:
            self.width_alignment = width_alignment
        if height_alignment is not None:
            self.height_alignment = height_alignment
        if max_bit_rate is not None:
            self.max_bit_rate = max_bit_rate
        if supported_color_formats is not None:
            self.supported_color_formats = supported_color_formats
        if supported_color_format_strings is not None:
            self.supported_color_format_strings = supported_color_format_strings
        if profile_and_level_information is not None:
            self.profile_and_level_information = profile_and_level_information
        if id is not None:
            self.id = id
        if direction is not None:
            self.direction = direction
        if name is not None:
            self.name = name
        if description is not None:
            self.description = description
        if framework_codec is not None:
            self.framework_codec = framework_codec
        if is_hardware_codec is not None:
            self.is_hardware_codec = is_hardware_codec
        if secondary_framework is not None:
            self.secondary_framework = secondary_framework
        if secondary_framework_codec is not None:
            self.secondary_framework_codec = secondary_framework_codec
        if max_instance_count is not None:
            self.max_instance_count = max_instance_count
        if is_enabled_by_default is not None:
            self.is_enabled_by_default = is_enabled_by_default
        if default_priority is not None:
            self.default_priority = default_priority

    @property
    def codec_device_info(self):
        """Gets the codec_device_info of this VideoCodecBase.  # noqa: E501


        :return: The codec_device_info of this VideoCodecBase.  # noqa: E501
        :rtype: CommonInterfacesICodecDeviceInfo
        """
        return self._codec_device_info

    @codec_device_info.setter
    def codec_device_info(self, codec_device_info):
        """Sets the codec_device_info of this VideoCodecBase.


        :param codec_device_info: The codec_device_info of this VideoCodecBase.  # noqa: E501
        :type: CommonInterfacesICodecDeviceInfo
        """

        self._codec_device_info = codec_device_info

    @property
    def codec_kind(self):
        """Gets the codec_kind of this VideoCodecBase.  # noqa: E501


        :return: The codec_kind of this VideoCodecBase.  # noqa: E501
        :rtype: CodecKinds
        """
        return self._codec_kind

    @codec_kind.setter
    def codec_kind(self, codec_kind):
        """Sets the codec_kind of this VideoCodecBase.


        :param codec_kind: The codec_kind of this VideoCodecBase.  # noqa: E501
        :type: CodecKinds
        """

        self._codec_kind = codec_kind

    @property
    def media_type_name(self):
        """Gets the media_type_name of this VideoCodecBase.  # noqa: E501


        :return: The media_type_name of this VideoCodecBase.  # noqa: E501
        :rtype: str
        """
        return self._media_type_name

    @media_type_name.setter
    def media_type_name(self, media_type_name):
        """Sets the media_type_name of this VideoCodecBase.


        :param media_type_name: The media_type_name of this VideoCodecBase.  # noqa: E501
        :type: str
        """

        self._media_type_name = media_type_name

    @property
    def video_media_type(self):
        """Gets the video_media_type of this VideoCodecBase.  # noqa: E501


        :return: The video_media_type of this VideoCodecBase.  # noqa: E501
        :rtype: VideoMediaTypes
        """
        return self._video_media_type

    @video_media_type.setter
    def video_media_type(self, video_media_type):
        """Sets the video_media_type of this VideoCodecBase.


        :param video_media_type: The video_media_type of this VideoCodecBase.  # noqa: E501
        :type: VideoMediaTypes
        """

        self._video_media_type = video_media_type

    @property
    def min_width(self):
        """Gets the min_width of this VideoCodecBase.  # noqa: E501


        :return: The min_width of this VideoCodecBase.  # noqa: E501
        :rtype: int
        """
        return self._min_width

    @min_width.setter
    def min_width(self, min_width):
        """Sets the min_width of this VideoCodecBase.


        :param min_width: The min_width of this VideoCodecBase.  # noqa: E501
        :type: int
        """

        self._min_width = min_width

    @property
    def max_width(self):
        """Gets the max_width of this VideoCodecBase.  # noqa: E501


        :return: The max_width of this VideoCodecBase.  # noqa: E501
        :rtype: int
        """
        return self._max_width

    @max_width.setter
    def max_width(self, max_width):
        """Sets the max_width of this VideoCodecBase.


        :param max_width: The max_width of this VideoCodecBase.  # noqa: E501
        :type: int
        """

        self._max_width = max_width

    @property
    def min_height(self):
        """Gets the min_height of this VideoCodecBase.  # noqa: E501


        :return: The min_height of this VideoCodecBase.  # noqa: E501
        :rtype: int
        """
        return self._min_height

    @min_height.setter
    def min_height(self, min_height):
        """Sets the min_height of this VideoCodecBase.


        :param min_height: The min_height of this VideoCodecBase.  # noqa: E501
        :type: int
        """

        self._min_height = min_height

    @property
    def max_height(self):
        """Gets the max_height of this VideoCodecBase.  # noqa: E501


        :return: The max_height of this VideoCodecBase.  # noqa: E501
        :rtype: int
        """
        return self._max_height

    @max_height.setter
    def max_height(self, max_height):
        """Sets the max_height of this VideoCodecBase.


        :param max_height: The max_height of this VideoCodecBase.  # noqa: E501
        :type: int
        """

        self._max_height = max_height

    @property
    def width_alignment(self):
        """Gets the width_alignment of this VideoCodecBase.  # noqa: E501


        :return: The width_alignment of this VideoCodecBase.  # noqa: E501
        :rtype: int
        """
        return self._width_alignment

    @width_alignment.setter
    def width_alignment(self, width_alignment):
        """Sets the width_alignment of this VideoCodecBase.


        :param width_alignment: The width_alignment of this VideoCodecBase.  # noqa: E501
        :type: int
        """

        self._width_alignment = width_alignment

    @property
    def height_alignment(self):
        """Gets the height_alignment of this VideoCodecBase.  # noqa: E501


        :return: The height_alignment of this VideoCodecBase.  # noqa: E501
        :rtype: int
        """
        return self._height_alignment

    @height_alignment.setter
    def height_alignment(self, height_alignment):
        """Sets the height_alignment of this VideoCodecBase.


        :param height_alignment: The height_alignment of this VideoCodecBase.  # noqa: E501
        :type: int
        """

        self._height_alignment = height_alignment

    @property
    def max_bit_rate(self):
        """Gets the max_bit_rate of this VideoCodecBase.  # noqa: E501


        :return: The max_bit_rate of this VideoCodecBase.  # noqa: E501
        :rtype: BitRate
        """
        return self._max_bit_rate

    @max_bit_rate.setter
    def max_bit_rate(self, max_bit_rate):
        """Sets the max_bit_rate of this VideoCodecBase.


        :param max_bit_rate: The max_bit_rate of this VideoCodecBase.  # noqa: E501
        :type: BitRate
        """

        self._max_bit_rate = max_bit_rate

    @property
    def supported_color_formats(self):
        """Gets the supported_color_formats of this VideoCodecBase.  # noqa: E501


        :return: The supported_color_formats of this VideoCodecBase.  # noqa: E501
        :rtype: list[ColorFormats]
        """
        return self._supported_color_formats

    @supported_color_formats.setter
    def supported_color_formats(self, supported_color_formats):
        """Sets the supported_color_formats of this VideoCodecBase.


        :param supported_color_formats: The supported_color_formats of this VideoCodecBase.  # noqa: E501
        :type: list[ColorFormats]
        """

        self._supported_color_formats = supported_color_formats

    @property
    def supported_color_format_strings(self):
        """Gets the supported_color_format_strings of this VideoCodecBase.  # noqa: E501


        :return: The supported_color_format_strings of this VideoCodecBase.  # noqa: E501
        :rtype: list[str]
        """
        return self._supported_color_format_strings

    @supported_color_format_strings.setter
    def supported_color_format_strings(self, supported_color_format_strings):
        """Sets the supported_color_format_strings of this VideoCodecBase.


        :param supported_color_format_strings: The supported_color_format_strings of this VideoCodecBase.  # noqa: E501
        :type: list[str]
        """

        self._supported_color_format_strings = supported_color_format_strings

    @property
    def profile_and_level_information(self):
        """Gets the profile_and_level_information of this VideoCodecBase.  # noqa: E501


        :return: The profile_and_level_information of this VideoCodecBase.  # noqa: E501
        :rtype: list[ProfileLevelInformation]
        """
        return self._profile_and_level_information

    @profile_and_level_information.setter
    def profile_and_level_information(self, profile_and_level_information):
        """Sets the profile_and_level_information of this VideoCodecBase.


        :param profile_and_level_information: The profile_and_level_information of this VideoCodecBase.  # noqa: E501
        :type: list[ProfileLevelInformation]
        """

        self._profile_and_level_information = profile_and_level_information

    @property
    def id(self):
        """Gets the id of this VideoCodecBase.  # noqa: E501


        :return: The id of this VideoCodecBase.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this VideoCodecBase.


        :param id: The id of this VideoCodecBase.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def direction(self):
        """Gets the direction of this VideoCodecBase.  # noqa: E501


        :return: The direction of this VideoCodecBase.  # noqa: E501
        :rtype: CodecDirections
        """
        return self._direction

    @direction.setter
    def direction(self, direction):
        """Sets the direction of this VideoCodecBase.


        :param direction: The direction of this VideoCodecBase.  # noqa: E501
        :type: CodecDirections
        """

        self._direction = direction

    @property
    def name(self):
        """Gets the name of this VideoCodecBase.  # noqa: E501


        :return: The name of this VideoCodecBase.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this VideoCodecBase.


        :param name: The name of this VideoCodecBase.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def description(self):
        """Gets the description of this VideoCodecBase.  # noqa: E501


        :return: The description of this VideoCodecBase.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this VideoCodecBase.


        :param description: The description of this VideoCodecBase.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def framework_codec(self):
        """Gets the framework_codec of this VideoCodecBase.  # noqa: E501


        :return: The framework_codec of this VideoCodecBase.  # noqa: E501
        :rtype: str
        """
        return self._framework_codec

    @framework_codec.setter
    def framework_codec(self, framework_codec):
        """Sets the framework_codec of this VideoCodecBase.


        :param framework_codec: The framework_codec of this VideoCodecBase.  # noqa: E501
        :type: str
        """

        self._framework_codec = framework_codec

    @property
    def is_hardware_codec(self):
        """Gets the is_hardware_codec of this VideoCodecBase.  # noqa: E501


        :return: The is_hardware_codec of this VideoCodecBase.  # noqa: E501
        :rtype: bool
        """
        return self._is_hardware_codec

    @is_hardware_codec.setter
    def is_hardware_codec(self, is_hardware_codec):
        """Sets the is_hardware_codec of this VideoCodecBase.


        :param is_hardware_codec: The is_hardware_codec of this VideoCodecBase.  # noqa: E501
        :type: bool
        """

        self._is_hardware_codec = is_hardware_codec

    @property
    def secondary_framework(self):
        """Gets the secondary_framework of this VideoCodecBase.  # noqa: E501


        :return: The secondary_framework of this VideoCodecBase.  # noqa: E501
        :rtype: SecondaryFrameworks
        """
        return self._secondary_framework

    @secondary_framework.setter
    def secondary_framework(self, secondary_framework):
        """Sets the secondary_framework of this VideoCodecBase.


        :param secondary_framework: The secondary_framework of this VideoCodecBase.  # noqa: E501
        :type: SecondaryFrameworks
        """

        self._secondary_framework = secondary_framework

    @property
    def secondary_framework_codec(self):
        """Gets the secondary_framework_codec of this VideoCodecBase.  # noqa: E501


        :return: The secondary_framework_codec of this VideoCodecBase.  # noqa: E501
        :rtype: str
        """
        return self._secondary_framework_codec

    @secondary_framework_codec.setter
    def secondary_framework_codec(self, secondary_framework_codec):
        """Sets the secondary_framework_codec of this VideoCodecBase.


        :param secondary_framework_codec: The secondary_framework_codec of this VideoCodecBase.  # noqa: E501
        :type: str
        """

        self._secondary_framework_codec = secondary_framework_codec

    @property
    def max_instance_count(self):
        """Gets the max_instance_count of this VideoCodecBase.  # noqa: E501


        :return: The max_instance_count of this VideoCodecBase.  # noqa: E501
        :rtype: int
        """
        return self._max_instance_count

    @max_instance_count.setter
    def max_instance_count(self, max_instance_count):
        """Sets the max_instance_count of this VideoCodecBase.


        :param max_instance_count: The max_instance_count of this VideoCodecBase.  # noqa: E501
        :type: int
        """

        self._max_instance_count = max_instance_count

    @property
    def is_enabled_by_default(self):
        """Gets the is_enabled_by_default of this VideoCodecBase.  # noqa: E501


        :return: The is_enabled_by_default of this VideoCodecBase.  # noqa: E501
        :rtype: bool
        """
        return self._is_enabled_by_default

    @is_enabled_by_default.setter
    def is_enabled_by_default(self, is_enabled_by_default):
        """Sets the is_enabled_by_default of this VideoCodecBase.


        :param is_enabled_by_default: The is_enabled_by_default of this VideoCodecBase.  # noqa: E501
        :type: bool
        """

        self._is_enabled_by_default = is_enabled_by_default

    @property
    def default_priority(self):
        """Gets the default_priority of this VideoCodecBase.  # noqa: E501


        :return: The default_priority of this VideoCodecBase.  # noqa: E501
        :rtype: int
        """
        return self._default_priority

    @default_priority.setter
    def default_priority(self, default_priority):
        """Sets the default_priority of this VideoCodecBase.


        :param default_priority: The default_priority of this VideoCodecBase.  # noqa: E501
        :type: int
        """

        self._default_priority = default_priority

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(VideoCodecBase, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, VideoCodecBase):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Emby Server REST API (BETA)
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from emby_client.api_client import ApiClient


class SessionsServiceApi(object):
    """NOTE: This class is auto generated.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def delete_auth_keys_by_key(self, key, **kwargs):  # noqa: E501
        """delete_auth_keys_by_key  # noqa: E501

        Requires authentication as administrator  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_auth_keys_by_key(key, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str key: Auth Key (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_auth_keys_by_key_with_http_info(key, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_auth_keys_by_key_with_http_info(key, **kwargs)  # noqa: E501
            return data

    def delete_auth_keys_by_key_with_http_info(self, key, **kwargs):  # noqa: E501
        """delete_auth_keys_by_key  # noqa: E501

        Requires authentication as administrator  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_auth_keys_by_key_with_http_info(key, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str key: Auth Key (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['key']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_auth_keys_by_key" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'key' is set
        if ('key' not in params or
                params['key'] is None):
            raise ValueError("Missing the required parameter `key` when calling `delete_auth_keys_by_key`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'key' in params:
            path_params['Key'] = params['key']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/Auth/Keys/{Key}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_sessions_by_id_users_by_userid(self, id, user_id, **kwargs):  # noqa: E501
        """Removes an additional user from a session  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_sessions_by_id_users_by_userid(id, user_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: Session Id (required)
        :param str user_id: UserId Id (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_sessions_by_id_users_by_userid_with_http_info(id, user_id, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_sessions_by_id_users_by_userid_with_http_info(id, user_id, **kwargs)  # noqa: E501
            return data

    def delete_sessions_by_id_users_by_userid_with_http_info(self, id, user_id, **kwargs):  # noqa: E501
        """Removes an additional user from a session  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_sessions_by_id_users_by_userid_with_http_info(id, user_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: Session Id (required)
        :param str user_id: UserId Id (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'user_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_sessions_by_id_users_by_userid" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `delete_sessions_by_id_users_by_userid`")  # noqa: E501
        # verify the required parameter 'user_id' is set
        if ('user_id' not in params or
                params['user_id'] is None):
            raise ValueError("Missing the required parameter `user_id` when calling `delete_sessions_by_id_users_by_userid`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['Id'] = params['id']  # noqa: E501
        if 'user_id' in params:
            path_params['UserId'] = params['user_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/Sessions/{Id}/Users/{UserId}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_auth_keys(self, **kwargs):  # noqa: E501
        """get_auth_keys  # noqa: E501

        Requires authentication as administrator  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_auth_keys(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int start_index: Optional. The record index to start at. All items with a lower index will be dropped from the results.
        :param int limit: Optional. The maximum number of records to return
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_auth_keys_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_auth_keys_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_auth_keys_with_http_info(self, **kwargs):  # noqa: E501
        """get_auth_keys  # noqa: E501

        Requires authentication as administrator  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_auth_keys_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int start_index: Optional. The record index to start at. All items with a lower index will be dropped from the results.
        :param int limit: Optional. The maximum number of records to return
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['start_index', 'limit']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_auth_keys" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'start_index' in params:
            query_params.append(('StartIndex', params['start_index']))  # noqa: E501
        if 'limit' in params:
            query_params.append(('Limit', params['limit']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/Auth/Keys', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_auth_providers(self, **kwargs):  # noqa: E501
        """get_auth_providers  # noqa: E501

        Requires authentication as administrator  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_auth_providers(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: list[NameIdPair]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_auth_providers_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_auth_providers_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_auth_providers_with_http_info(self, **kwargs):  # noqa: E501
        """get_auth_providers  # noqa: E501

        Requires authentication as administrator  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_auth_providers_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: list[NameIdPair]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_auth_providers" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/Auth/Providers', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[NameIdPair]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_sessions(self, **kwargs):  # noqa: E501
        """Gets a list of sessions  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_sessions(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str controllable_by_user_id: Optional. Filter by sessions that a given user is allowed to remote control.
        :param str device_id: Optional. Filter by device id.
        :param str id: Optional. Filter by session id.
        :return: list[SessionSessionInfo]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_sessions_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_sessions_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_sessions_with_http_info(self, **kwargs):  # noqa: E501
        """Gets a list of sessions  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_sessions_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str controllable_by_user_id: Optional. Filter by sessions that a given user is allowed to remote control.
        :param str device_id: Optional. Filter by device id.
        :param str id: Optional. Filter by session id.
        :return: list[SessionSessionInfo]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['controllable_by_user_id', 'device_id', 'id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_sessions" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'controllable_by_user_id' in params:
            query_params.append(('ControllableByUserId', params['controllable_by_user_id']))  # noqa: E501
        if 'device_id' in params:
            query_params.append(('DeviceId', params['device_id']))  # noqa: E501
        if 'id' in params:
            query_params.append(('Id', params['id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/Sessions', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[SessionSessionInfo]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_sessions_playqueue(self, **kwargs):  # noqa: E501
        """Gets a the current play queue from a session  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_sessions_playqueue(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: Optional. Filter by session id.
        :param str device_id: Optional. Filter by device id.
        :return: QueryResultBaseItemDto
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_sessions_playqueue_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_sessions_playqueue_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_sessions_playqueue_with_http_info(self, **kwargs):  # noqa: E501
        """Gets a the current play queue from a session  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_sessions_playqueue_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: Optional. Filter by session id.
        :param str device_id: Optional. Filter by device id.
        :return: QueryResultBaseItemDto
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'device_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_sessions_playqueue" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'id' in params:
            query_params.append(('Id', params['id']))  # noqa: E501
        if 'device_id' in params:
            query_params.append(('DeviceId', params['device_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/Sessions/PlayQueue', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='QueryResultBaseItemDto',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def post_auth_keys(self, app, **kwargs):  # noqa: E501
        """post_auth_keys  # noqa: E501

        Requires authentication as administrator  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_auth_keys(app, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str app: App (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.post_auth_keys_with_http_info(app, **kwargs)  # noqa: E501
        else:
            (data) = self.post_auth_keys_with_http_info(app, **kwargs)  # noqa: E501
            return data

    def post_auth_keys_with_http_info(self, app, **kwargs):  # noqa: E501
        """post_auth_keys  # noqa: E501

        Requires authentication as administrator  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_auth_keys_with_http_info(app, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str app: App (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['app']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_auth_keys" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'app' is set
        if ('app' not in params or
                params['app'] is None):
            raise ValueError("Missing the required parameter `app` when calling `post_auth_keys`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'app' in params:
            query_params.append(('App', params['app']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/Auth/Keys', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def post_auth_keys_by_key_delete(self, key, **kwargs):  # noqa: E501
        """post_auth_keys_by_key_delete  # noqa: E501

        Requires authentication as administrator  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_auth_keys_by_key_delete(key, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str key: Auth Key (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.post_auth_keys_by_key_delete_with_http_info(key, **kwargs)  # noqa: E501
        else:
            (data) = self.post_auth_keys_by_key_delete_with_http_info(key, **kwargs)  # noqa: E501
            return data

    def post_auth_keys_by_key_delete_with_http_info(self, key, **kwargs):  # noqa: E501
        """post_auth_keys_by_key_delete  # noqa: E501

        Requires authentication as administrator  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_auth_keys_by_key_delete_with_http_info(key, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str key: Auth Key (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['key']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_auth_keys_by_key_delete" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'key' is set
        if ('key' not in params or
                params['key'] is None):
            raise ValueError("Missing the required parameter `key` when calling `post_auth_keys_by_key_delete`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'key' in params:
            path_params['Key'] = params['key']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/Auth/Keys/{Key}/Delete', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def post_sessions_by_id_command(self, body, id, **kwargs):  # noqa: E501
        """Issues a system command to a client  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_sessions_by_id_command(body, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param GeneralCommand body: GeneralCommand:  (required)
        :param str id: Session Id (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.post_sessions_by_id_command_with_http_info(body, id, **kwargs)  # noqa: E501
        else:
            (data) = self.post_sessions_by_id_command_with_http_info(body, id, **kwargs)  # noqa: E501
            return data

    def post_sessions_by_id_command_with_http_info(self, body, id, **kwargs):  # noqa: E501
        """Issues a system command to a client  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_sessions_by_id_command_with_http_info(body, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param GeneralCommand body: GeneralCommand:  (required)
        :param str id: Session Id (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_sessions_by_id_command" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `post_sessions_by_id_command`")  # noqa: E501
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `post_sessions_by_id_command`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['Id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/Sessions/{Id}/Command', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def post_sessions_by_id_command_by_command(self, id, command, **kwargs):  # noqa: E501
        """Issues a system command to a client  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_sessions_by_id_command_by_command(id, command, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: Session Id (required)
        :param str command: The command to send. (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.post_sessions_by_id_command_by_command_with_http_info(id, command, **kwargs)  # noqa: E501
        else:
            (data) = self.post_sessions_by_id_command_by_command_with_http_info(id, command, **kwargs)  # noqa: E501
            return data

    def post_sessions_by_id_command_by_command_with_http_info(self, id, command, **kwargs):  # noqa: E501
        """Issues a system command to a client  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_sessions_by_id_command_by_command_with_http_info(id, command, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: Session Id (required)
        :param str command: The command to send. (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'command']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_sessions_by_id_command_by_command" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `post_sessions_by_id_command_by_command`")  # noqa: E501
        # verify the required parameter 'command' is set
        if ('command' not in params or
                params['command'] is None):
            raise ValueError("Missing the required parameter `command` when calling `post_sessions_by_id_command_by_command`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['Id'] = params['id']  # noqa: E501
        if 'command' in params:
            path_params['Command'] = params['command']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/Sessions/{Id}/Command/{Command}', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def post_sessions_by_id_message(self, id, text, header, **kwargs):  # noqa: E501
        """Issues a command to a client to display a message to the user  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_sessions_by_id_message(id, text, header, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: Session Id (required)
        :param str text: The message text. (required)
        :param str header: The message header. (required)
        :param int timeout_ms: The message timeout. If omitted the user will have to confirm viewing the message.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.post_sessions_by_id_message_with_http_info(id, text, header, **kwargs)  # noqa: E501
        else:
            (data) = self.post_sessions_by_id_message_with_http_info(id, text, header, **kwargs)  # noqa: E501
            return data

    def post_sessions_by_id_message_with_http_info(self, id, text, header, **kwargs):  # noqa: E501
        """Issues a command to a client to display a message to the user  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_sessions_by_id_message_with_http_info(id, text, header, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: Session Id (required)
        :param str text: The message text. (required)
        :param str header: The message header. (required)
        :param int timeout_ms: The message timeout. If omitted the user will have to confirm viewing the message.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'text', 'header', 'timeout_ms']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_sessions_by_id_message" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `post_sessions_by_id_message`")  # noqa: E501
        # verify the required parameter 'text' is set
        if ('text' not in params or
                params['text'] is None):
            raise ValueError("Missing the required parameter `text` when calling `post_sessions_by_id_message`")  # noqa: E501
        # verify the required parameter 'header' is set
        if ('header' not in params or
                params['header'] is None):
            raise ValueError("Missing the required parameter `header` when calling `post_sessions_by_id_message`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['Id'] = params['id']  # noqa: E501

        query_params = []
        if 'text' in params:
            query_params.append(('Text', params['text']))  # noqa: E501
        if 'header' in params:
            query_params.append(('Header', params['header']))  # noqa: E501
        if 'timeout_ms' in params:
            query_params.append(('TimeoutMs', params['timeout_ms']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/Sessions/{Id}/Message', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def post_sessions_by_id_playing(self, body, item_ids, play_command, id, **kwargs):  # noqa: E501
        """Instructs a session to play an item  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_sessions_by_id_playing(body, item_ids, play_command, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param PlayRequest body: PlayRequest:  (required)
        :param list[int] item_ids: The ids of the items to play, comma delimited (required)
        :param PlayCommand play_command: The type of play command to issue (PlayNow, PlayNext, PlayLast). Clients who have not yet implemented play next and play last may play now. (required)
        :param str id: Session Id (required)
        :param int start_position_ticks: The starting position of the first item.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.post_sessions_by_id_playing_with_http_info(body, item_ids, play_command, id, **kwargs)  # noqa: E501
        else:
            (data) = self.post_sessions_by_id_playing_with_http_info(body, item_ids, play_command, id, **kwargs)  # noqa: E501
            return data

    def post_sessions_by_id_playing_with_http_info(self, body, item_ids, play_command, id, **kwargs):  # noqa: E501
        """Instructs a session to play an item  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_sessions_by_id_playing_with_http_info(body, item_ids, play_command, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param PlayRequest body: PlayRequest:  (required)
        :param list[int] item_ids: The ids of the items to play, comma delimited (required)
        :param PlayCommand play_command: The type of play command to issue (PlayNow, PlayNext, PlayLast). Clients who have not yet implemented play next and play last may play now. (required)
        :param str id: Session Id (required)
        :param int start_position_ticks: The starting position of the first item.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'item_ids', 'play_command', 'id', 'start_position_ticks']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_sessions_by_id_playing" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `post_sessions_by_id_playing`")  # noqa: E501
        # verify the required parameter 'item_ids' is set
        if ('item_ids' not in params or
                params['item_ids'] is None):
            raise ValueError("Missing the required parameter `item_ids` when calling `post_sessions_by_id_playing`")  # noqa: E501
        # verify the required parameter 'play_command' is set
        if ('play_command' not in params or
                params['play_command'] is None):
            raise ValueError("Missing the required parameter `play_command` when calling `post_sessions_by_id_playing`")  # noqa: E501
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `post_sessions_by_id_playing`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['Id'] = params['id']  # noqa: E501

        query_params = []
        if 'item_ids' in params:
            query_params.append(('ItemIds', params['item_ids']))  # noqa: E501
            collection_formats['ItemIds'] = 'multi'  # noqa: E501
        if 'start_position_ticks' in params:
            query_params.append(('StartPositionTicks', params['start_position_ticks']))  # noqa: E501
        if 'play_command' in params:
            query_params.append(('PlayCommand', params['play_command']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/Sessions/{Id}/Playing', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def post_sessions_by_id_playing_by_command(self, body, id, command, **kwargs):  # noqa: E501
        """Issues a playstate command to a client  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_sessions_by_id_playing_by_command(body, id, command, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param PlaystateRequest body: PlaystateRequest:  (required)
        :param str id: Session Id (required)
        :param PlaystateCommand command: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.post_sessions_by_id_playing_by_command_with_http_info(body, id, command, **kwargs)  # noqa: E501
        else:
            (data) = self.post_sessions_by_id_playing_by_command_with_http_info(body, id, command, **kwargs)  # noqa: E501
            return data

    def post_sessions_by_id_playing_by_command_with_http_info(self, body, id, command, **kwargs):  # noqa: E501
        """Issues a playstate command to a client  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_sessions_by_id_playing_by_command_with_http_info(body, id, command, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param PlaystateRequest body: PlaystateRequest:  (required)
        :param str id: Session Id (required)
        :param PlaystateCommand command: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'id', 'command']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_sessions_by_id_playing_by_command" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `post_sessions_by_id_playing_by_command`")  # noqa: E501
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `post_sessions_by_id_playing_by_command`")  # noqa: E501
        # verify the required parameter 'command' is set
        if ('command' not in params or
                params['command'] is None):
            raise ValueError("Missing the required parameter `command` when calling `post_sessions_by_id_playing_by_command`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['Id'] = params['id']  # noqa: E501
        if 'command' in params:
            path_params['Command'] = params['command']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/Sessions/{Id}/Playing/{Command}', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def post_sessions_by_id_system_by_command(self, id, command, **kwargs):  # noqa: E501
        """Issues a system command to a client  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_sessions_by_id_system_by_command(id, command, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: Session Id (required)
        :param str command: The command to send. (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.post_sessions_by_id_system_by_command_with_http_info(id, command, **kwargs)  # noqa: E501
        else:
            (data) = self.post_sessions_by_id_system_by_command_with_http_info(id, command, **kwargs)  # noqa: E501
            return data

    def post_sessions_by_id_system_by_command_with_http_info(self, id, command, **kwargs):  # noqa: E501
        """Issues a system command to a client  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_sessions_by_id_system_by_command_with_http_info(id, command, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: Session Id (required)
        :param str command: The command to send. (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'command']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_sessions_by_id_system_by_command" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `post_sessions_by_id_system_by_command`")  # noqa: E501
        # verify the required parameter 'command' is set
        if ('command' not in params or
                params['command'] is None):
            raise ValueError("Missing the required parameter `command` when calling `post_sessions_by_id_system_by_command`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['Id'] = params['id']  # noqa: E501
        if 'command' in params:
            path_params['Command'] = params['command']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/Sessions/{Id}/System/{Command}', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def post_sessions_by_id_users_by_userid(self, id, user_id, **kwargs):  # noqa: E501
        """Adds an additional user to a session  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_sessions_by_id_users_by_userid(id, user_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: Session Id (required)
        :param str user_id: UserId Id (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.post_sessions_by_id_users_by_userid_with_http_info(id, user_id, **kwargs)  # noqa: E501
        else:
            (data) = self.post_sessions_by_id_users_by_userid_with_http_info(id, user_id, **kwargs)  # noqa: E501
            return data

    def post_sessions_by_id_users_by_userid_with_http_info(self, id, user_id, **kwargs):  # noqa: E501
        """Adds an additional user to a session  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_sessions_by_id_users_by_userid_with_http_info(id, user_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: Session Id (required)
        :param str user_id: UserId Id (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'user_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_sessions_by_id_users_by_userid" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `post_sessions_by_id_users_by_userid`")  # noqa: E501
        # verify the required parameter 'user_id' is set
        if ('user_id' not in params or
                params['user_id'] is None):
            raise ValueError("Missing the required parameter `user_id` when calling `post_sessions_by_id_users_by_userid`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['Id'] = params['id']  # noqa: E501
        if 'user_id' in params:
            path_params['UserId'] = params['user_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/Sessions/{Id}/Users/{UserId}', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def post_sessions_by_id_users_by_userid_delete(self, id, user_id, **kwargs):  # noqa: E501
        """Removes an additional user from a session  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_sessions_by_id_users_by_userid_delete(id, user_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: Session Id (required)
        :param str user_id: UserId Id (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.post_sessions_by_id_users_by_userid_delete_with_http_info(id, user_id, **kwargs)  # noqa: E501
        else:
            (data) = self.post_sessions_by_id_users_by_userid_delete_with_http_info(id, user_id, **kwargs)  # noqa: E501
            return data

    def post_sessions_by_id_users_by_userid_delete_with_http_info(self, id, user_id, **kwargs):  # noqa: E501
        """Removes an additional user from a session  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_sessions_by_id_users_by_userid_delete_with_http_info(id, user_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: Session Id (required)
        :param str user_id: UserId Id (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'user_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_sessions_by_id_users_by_userid_delete" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `post_sessions_by_id_users_by_userid_delete`")  # noqa: E501
        # verify the required parameter 'user_id' is set
        if ('user_id' not in params or
                params['user_id'] is None):
            raise ValueError("Missing the required parameter `user_id` when calling `post_sessions_by_id_users_by_userid_delete`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['Id'] = params['id']  # noqa: E501
        if 'user_id' in params:
            path_params['UserId'] = params['user_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/Sessions/{Id}/Users/{UserId}/Delete', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def post_sessions_by_id_viewing(self, id, item_type, item_id, item_name, **kwargs):  # noqa: E501
        """Instructs a session to browse to an item or view  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_sessions_by_id_viewing(id, item_type, item_id, item_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: Session Id (required)
        :param str item_type: The type of item to browse to. (required)
        :param str item_id: The Id of the item. (required)
        :param str item_name: The name of the item. (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.post_sessions_by_id_viewing_with_http_info(id, item_type, item_id, item_name, **kwargs)  # noqa: E501
        else:
            (data) = self.post_sessions_by_id_viewing_with_http_info(id, item_type, item_id, item_name, **kwargs)  # noqa: E501
            return data

    def post_sessions_by_id_viewing_with_http_info(self, id, item_type, item_id, item_name, **kwargs):  # noqa: E501
        """Instructs a session to browse to an item or view  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_sessions_by_id_viewing_with_http_info(id, item_type, item_id, item_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: Session Id (required)
        :param str item_type: The type of item to browse to. (required)
        :param str item_id: The Id of the item. (required)
        :param str item_name: The name of the item. (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'item_type', 'item_id', 'item_name']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_sessions_by_id_viewing" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `post_sessions_by_id_viewing`")  # noqa: E501
        # verify the required parameter 'item_type' is set
        if ('item_type' not in params or
                params['item_type'] is None):
            raise ValueError("Missing the required parameter `item_type` when calling `post_sessions_by_id_viewing`")  # noqa: E501
        # verify the required parameter 'item_id' is set
        if ('item_id' not in params or
                params['item_id'] is None):
            raise ValueError("Missing the required parameter `item_id` when calling `post_sessions_by_id_viewing`")  # noqa: E501
        # verify the required parameter 'item_name' is set
        if ('item_name' not in params or
                params['item_name'] is None):
            raise ValueError("Missing the required parameter `item_name` when calling `post_sessions_by_id_viewing`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['Id'] = params['id']  # noqa: E501

        query_params = []
        if 'item_type' in params:
            query_params.append(('ItemType', params['item_type']))  # noqa: E501
        if 'item_id' in params:
            query_params.append(('ItemId', params['item_id']))  # noqa: E501
        if 'item_name' in params:
            query_params.append(('ItemName', params['item_name']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/Sessions/{Id}/Viewing', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def post_sessions_capabilities(self, id, **kwargs):  # noqa: E501
        """Updates capabilities for a device  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_sessions_capabilities(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: Session Id (required)
        :param str playable_media_types: A list of playable media types, comma delimited. Audio, Video, Book, Game, Photo.
        :param str supported_commands: A list of supported remote control commands, comma delimited
        :param bool supports_media_control: Determines whether media can be played remotely.
        :param bool supports_sync: Determines whether sync is supported.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.post_sessions_capabilities_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.post_sessions_capabilities_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def post_sessions_capabilities_with_http_info(self, id, **kwargs):  # noqa: E501
        """Updates capabilities for a device  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_sessions_capabilities_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: Session Id (required)
        :param str playable_media_types: A list of playable media types, comma delimited. Audio, Video, Book, Game, Photo.
        :param str supported_commands: A list of supported remote control commands, comma delimited
        :param bool supports_media_control: Determines whether media can be played remotely.
        :param bool supports_sync: Determines whether sync is supported.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'playable_media_types', 'supported_commands', 'supports_media_control', 'supports_sync']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_sessions_capabilities" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `post_sessions_capabilities`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'id' in params:
            query_params.append(('Id', params['id']))  # noqa: E501
        if 'playable_media_types' in params:
            query_params.append(('PlayableMediaTypes', params['playable_media_types']))  # noqa: E501
        if 'supported_commands' in params:
            query_params.append(('SupportedCommands', params['supported_commands']))  # noqa: E501
        if 'supports_media_control' in params:
            query_params.append(('SupportsMediaControl', params['supports_media_control']))  # noqa: E501
        if 'supports_sync' in params:
            query_params.append(('SupportsSync', params['supports_sync']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/Sessions/Capabilities', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def post_sessions_capabilities_full(self, body, id, **kwargs):  # noqa: E501
        """Updates capabilities for a device  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_sessions_capabilities_full(body, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ClientCapabilities body: ClientCapabilities:  (required)
        :param str id: Session Id (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.post_sessions_capabilities_full_with_http_info(body, id, **kwargs)  # noqa: E501
        else:
            (data) = self.post_sessions_capabilities_full_with_http_info(body, id, **kwargs)  # noqa: E501
            return data

    def post_sessions_capabilities_full_with_http_info(self, body, id, **kwargs):  # noqa: E501
        """Updates capabilities for a device  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_sessions_capabilities_full_with_http_info(body, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ClientCapabilities body: ClientCapabilities:  (required)
        :param str id: Session Id (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_sessions_capabilities_full" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `post_sessions_capabilities_full`")  # noqa: E501
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `post_sessions_capabilities_full`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'id' in params:
            query_params.append(('Id', params['id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/Sessions/Capabilities/Full', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def post_sessions_logout(self, **kwargs):  # noqa: E501
        """Reports that a session has ended  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_sessions_logout(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.post_sessions_logout_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.post_sessions_logout_with_http_info(**kwargs)  # noqa: E501
            return data

    def post_sessions_logout_with_http_info(self, **kwargs):  # noqa: E501
        """Reports that a session has ended  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_sessions_logout_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_sessions_logout" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/Sessions/Logout', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Emby Server REST API (BETA)
"""

import pprint
import re  # noqa: F401

import six

class LibraryOptionsResult(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'metadata_savers': 'list[LibraryOptionInfo]',
        'metadata_readers': 'list[LibraryOptionInfo]',
        'subtitle_fetchers': 'list[LibraryOptionInfo]',
        'lyrics_fetchers': 'list[LibraryOptionInfo]',
        'type_options': 'list[LibraryTypeOptions]'
    }

    attribute_map = {
        'metadata_savers': 'MetadataSavers',
        'metadata_readers': 'MetadataReaders',
        'subtitle_fetchers': 'SubtitleFetchers',
        'lyrics_fetchers': 'LyricsFetchers',
        'type_options': 'TypeOptions'
    }

    def __init__(self, metadata_savers=None, metadata_readers=None, subtitle_fetchers=None, lyrics_fetchers=None, type_options=None):  # noqa: E501
        """LibraryOptionsResult - a model defined in Swagger"""  # noqa: E501
        self._metadata_savers = None
        self._metadata_readers = None
        self._subtitle_fetchers = None
        self._lyrics_fetchers = None
        self._type_options = None
        self.discriminator = None
        if metadata_savers is not None:
            self.metadata_savers = metadata_savers
        if metadata_readers is not None:
            self.metadata_readers = metadata_readers
        if subtitle_fetchers is not None:
            self.subtitle_fetchers = subtitle_fetchers
        if lyrics_fetchers is not None:
            self.lyrics_fetchers = lyrics_fetchers
        if type_options is not None:
            self.type_options = type_options

    @property
    def metadata_savers(self):
        """Gets the metadata_savers of this LibraryOptionsResult.  # noqa: E501


        :return: The metadata_savers of this LibraryOptionsResult.  # noqa: E501
        :rtype: list[LibraryOptionInfo]
        """
        return self._metadata_savers

    @metadata_savers.setter
    def metadata_savers(self, metadata_savers):
        """Sets the metadata_savers of this LibraryOptionsResult.


        :param metadata_savers: The metadata_savers of this LibraryOptionsResult.  # noqa: E501
        :type: list[LibraryOptionInfo]
        """

        self._metadata_savers = metadata_savers

    @property
    def metadata_readers(self):
        """Gets the metadata_readers of this LibraryOptionsResult.  # noqa: E501


        :return: The metadata_readers of this LibraryOptionsResult.  # noqa: E501
        :rtype: list[LibraryOptionInfo]
        """
        return self._metadata_readers

    @metadata_readers.setter
    def metadata_readers(self, metadata_readers):
        """Sets the metadata_readers of this LibraryOptionsResult.


        :param metadata_readers: The metadata_readers of this LibraryOptionsResult.  # noqa: E501
        :type: list[LibraryOptionInfo]
        """

        self._metadata_readers = metadata_readers

    @property
    def subtitle_fetchers(self):
        """Gets the subtitle_fetchers of this LibraryOptionsResult.  # noqa: E501


        :return: The subtitle_fetchers of this LibraryOptionsResult.  # noqa: E501
        :rtype: list[LibraryOptionInfo]
        """
        return self._subtitle_fetchers

    @subtitle_fetchers.setter
    def subtitle_fetchers(self, subtitle_fetchers):
        """Sets the subtitle_fetchers of this LibraryOptionsResult.


        :param subtitle_fetchers: The subtitle_fetchers of this LibraryOptionsResult.  # noqa: E501
        :type: list[LibraryOptionInfo]
        """

        self._subtitle_fetchers = subtitle_fetchers

    @property
    def lyrics_fetchers(self):
        """Gets the lyrics_fetchers of this LibraryOptionsResult.  # noqa: E501


        :return: The lyrics_fetchers of this LibraryOptionsResult.  # noqa: E501
        :rtype: list[LibraryOptionInfo]
        """
        return self._lyrics_fetchers

    @lyrics_fetchers.setter
    def lyrics_fetchers(self, lyrics_fetchers):
        """Sets the lyrics_fetchers of this LibraryOptionsResult.


        :param lyrics_fetchers: The lyrics_fetchers of this LibraryOptionsResult.  # noqa: E501
        :type: list[LibraryOptionInfo]
        """

        self._lyrics_fetchers = lyrics_fetchers

    @property
    def type_options(self):
        """Gets the type_options of this LibraryOptionsResult.  # noqa: E501


        :return: The type_options of this LibraryOptionsResult.  # noqa: E501
        :rtype: list[LibraryTypeOptions]
        """
        return self._type_options

    @type_options.setter
    def type_options(self, type_options):
        """Sets the type_options of this LibraryOptionsResult.


        :param type_options: The type_options of this LibraryOptionsResult.  # noqa: E501
        :type: list[LibraryTypeOptions]
        """

        self._type_options = type_options

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(LibraryOptionsResult, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, LibraryOptionsResult):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Emby Server REST API (BETA)
"""

import pprint
import re  # noqa: F401

import six

class ConnectUserLinkResult(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'is_pending': 'bool',
        'is_new_user_invitation': 'bool',
        'guest_display_name': 'str'
    }

    attribute_map = {
        'is_pending': 'IsPending',
        'is_new_user_invitation': 'IsNewUserInvitation',
        'guest_display_name': 'GuestDisplayName'
    }

    def __init__(self, is_pending=None, is_new_user_invitation=None, guest_display_name=None):  # noqa: E501
        """ConnectUserLinkResult - a model defined in Swagger"""  # noqa: E501
        self._is_pending = None
        self._is_new_user_invitation = None
        self._guest_display_name = None
        self.discriminator = None
        if is_pending is not None:
            self.is_pending = is_pending
        if is_new_user_invitation is not None:
            self.is_new_user_invitation = is_new_user_invitation
        if guest_display_name is not None:
            self.guest_display_name = guest_display_name

    @property
    def is_pending(self):
        """Gets the is_pending of this ConnectUserLinkResult.  # noqa: E501


        :return: The is_pending of this ConnectUserLinkResult.  # noqa: E501
        :rtype: bool
        """
        return self._is_pending

    @is_pending.setter
    def is_pending(self, is_pending):
        """Sets the is_pending of this ConnectUserLinkResult.


        :param is_pending: The is_pending of this ConnectUserLinkResult.  # noqa: E501
        :type: bool
        """

        self._is_pending = is_pending

    @property
    def is_new_user_invitation(self):
        """Gets the is_new_user_invitation of this ConnectUserLinkResult.  # noqa: E501


        :return: The is_new_user_invitation of this ConnectUserLinkResult.  # noqa: E501
        :rtype: bool
        """
        return self._is_new_user_invitation

    @is_new_user_invitation.setter
    def is_new_user_invitation(self, is_new_user_invitation):
        """Sets the is_new_user_invitation of this ConnectUserLinkResult.


        :param is_new_user_invitation: The is_new_user_invitation of this ConnectUserLinkResult.  # noqa: E501
        :type: bool
        """

        self._is_new_user_invitation = is_new_user_invitation

    @property
    def guest_display_name(self):
        """Gets the guest_display_name of this ConnectUserLinkResult.  # noqa: E501


        :return: The guest_display_name of this ConnectUserLinkResult.  # noqa: E501
        :rtype: str
        """
        return self._guest_display_name

    @guest_display_name.setter
    def guest_display_name(self, guest_display_name):
        """Sets the guest_display_name of this ConnectUserLinkResult.


        :param guest_display_name: The guest_display_name of this ConnectUserLinkResult.  # noqa: E501
        :type: str
        """

        self._guest_display_name = guest_display_name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ConnectUserLinkResult, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ConnectUserLinkResult):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Emby Server REST API (BETA)
"""

import pprint
import re  # noqa: F401

import six

class TranscodeReason(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    allowed enum values
    """
    CONTAINERNOTSUPPORTED = "ContainerNotSupported"
    VIDEOCODECNOTSUPPORTED = "VideoCodecNotSupported"
    AUDIOCODECNOTSUPPORTED = "AudioCodecNotSupported"
    CONTAINERBITRATEEXCEEDSLIMIT = "ContainerBitrateExceedsLimit"
    AUDIOBITRATENOTSUPPORTED = "AudioBitrateNotSupported"
    AUDIOCHANNELSNOTSUPPORTED = "AudioChannelsNotSupported"
    VIDEORESOLUTIONNOTSUPPORTED = "VideoResolutionNotSupported"
    UNKNOWNVIDEOSTREAMINFO = "UnknownVideoStreamInfo"
    UNKNOWNAUDIOSTREAMINFO = "UnknownAudioStreamInfo"
    AUDIOPROFILENOTSUPPORTED = "AudioProfileNotSupported"
    AUDIOSAMPLERATENOTSUPPORTED = "AudioSampleRateNotSupported"
    ANAMORPHICVIDEONOTSUPPORTED = "AnamorphicVideoNotSupported"
    INTERLACEDVIDEONOTSUPPORTED = "InterlacedVideoNotSupported"
    SECONDARYAUDIONOTSUPPORTED = "SecondaryAudioNotSupported"
    REFFRAMESNOTSUPPORTED = "RefFramesNotSupported"
    VIDEOBITDEPTHNOTSUPPORTED = "VideoBitDepthNotSupported"
    VIDEOBITRATENOTSUPPORTED = "VideoBitrateNotSupported"
    VIDEOFRAMERATENOTSUPPORTED = "VideoFramerateNotSupported"
    VIDEOLEVELNOTSUPPORTED = "VideoLevelNotSupported"
    VIDEOPROFILENOTSUPPORTED = "VideoProfileNotSupported"
    AUDIOBITDEPTHNOTSUPPORTED = "AudioBitDepthNotSupported"
    SUBTITLECODECNOTSUPPORTED = "SubtitleCodecNotSupported"
    DIRECTPLAYERROR = "DirectPlayError"
    VIDEORANGENOTSUPPORTED = "VideoRangeNotSupported"
    SUBTITLECONTENTOPTIONSENABLED = "SubtitleContentOptionsEnabled"
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
    }

    attribute_map = {
    }

    def __init__(self):  # noqa: E501
        """TranscodeReason - a model defined in Swagger"""  # noqa: E501
        self.discriminator = None

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(TranscodeReason, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TranscodeReason):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
